# pyCHomP2

CHomP (Computational Homology Project) with Python bindings

## Installation

To get the latest tagged version from the PyPi repository:

```bash
pip install pychomp2
```

To uninstall:

```bash
pip uninstall pychomp2
```

## Installing from source

To get the bleeding edge version (i.e., this repo):

```bash
git clone https://github.com/marciogameiro/pyCHomP2.git
cd pyCHomP2
git submodule update --init --recursive
pip install . --ignore-installed --no-cache-dir -v -v -v --user
```
